% pdg.cls
% Format reviews for PDG
% 2018-Mar-08  Jeffrey Anderson JDAnderson (at) lbl.gov

\ProvidesClass{pdg}[2018/03/21 version 1.01 PDG review format]
\NeedsTeXFormat{LaTeX2e}
\RequirePackage{xifthen} % for conditional statements


% This class extends the book class

\newif\ifrppbook
\newif\ifrppweb
\newif\ifrppbooklet
\newcommand{\baseclass}{extbook}

\@ifclasswith{pdg}{rppbook}{\rppbooktrue}{\rppbookfalse}
\@ifclasswith{pdg}{rppweb}{\rppwebtrue}{\rppwebfalse}
\@ifclasswith{pdg}{rppbooklet}{\rppbooklettrue}{\rppbookletfalse}

% \isbook and \isweb are booleans that can be passed on the command line to set or override class options given in the review source files.
\ifdefined\isbook
\rppbooktrue
\rppwebfalse
\rppbookletfalse
\fi

\ifdefined\isweb
\rppwebtrue
\rppbookfalse
\rppbookletfalse
\fi

\ifdefined\isbooklet
\rppbooklettrue
\rppwebfalse
\rppbookfalse
\fi

% If neither book nor web is specified, assume draft
\ifthenelse{\isundefined\isbook \AND \isundefined\isweb \AND \isundefined\isbooklet}{\def\isdraft{1}}{}

\ifdefined\isdraft
\rppwebtrue
\rppbookfalse
\rppbookletfalse
\fi



% Set default options to pass to base class
\DeclareOption{rppbook} {%
  \PassOptionsToClass{10pt,twoside,twocolumn}{\baseclass}
}

\DeclareOption{rppweb} {%
  \PassOptionsToClass{11pt,onecolumn}{\baseclass}
}

\DeclareOption{rppbooklet} {%
  \PassOptionsToClass{8pt,onecolumn}{\baseclass}
}

%\DeclareOption{draft} {}

% Pass through any other options
\DeclareOption*{%
  \PassOptionsToClass{\CurrentOption}{\baseclass}}


\ifrppbook
\ExecuteOptions{rppbook} % rppbook is default
\fi

\ifrppweb
\ExecuteOptions{rppweb} 
\fi

\ifrppbooklet
\ExecuteOptions{rppbooklet}
\fi

\ProcessOptions\relax

% Load base class
\LoadClass{\baseclass}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Many external packages and definitions.  These will be replaced with canonical definitions in the final version.

\RequirePackage{color}
\RequirePackage{float} % to control figure placement

%\RequirePackage{amsmath}


\RequirePackage{graphicx}  % to include figures (can also use other packages)
% Set default graphics width to be one column of a two-column page.
\setkeys{Gin}{width=0.49\textwidth}

\RequirePackage{xspace} 
%\input{lhcb-symbols-def} % Add in the predefined LHCb symbols
%\RequirePackage{cite} % Allows for ranges in citations
%\RequirePackage{mciteplus}


\newcommand{\pdgfigure}[5]{
\ifthenelse{\isempty{#4}}{%
  \begin{figure}[h]}{%
  \begin{figure}[#4]}
    \centering
    \includegraphics[#5]{figures/#1}
    \caption{#2.}\label{#3}
  \end{figure}
}

\newcommand{\pdgwidefigure}[5]{
\ifthenelse{\isempty{#4}}{%
  \begin{figure*}[h]}{%
  \begin{figure*}[#4]}
    \centering
    \includegraphics[width=\textwidth,#5]{figures/#1}
    \caption{#2.}\label{#3}
  \end{figure*}
}



\newenvironment{pdgtable}[4]{% #1
\ifthenelse{\isempty{#4}}{%
  \begin{table}[h]}{%
  \begin{table}[#4]}
    \centering
    \caption{#2.}
    \label{#3}
    \begin{tabular}{#1}
        \hline\hline
}{%
  \hline\hline
    \end{tabular}
    \end{table}
}

\newenvironment{pdgwidetable}[4]{%
\ifthenelse{\isempty{#4}}{%
  \begin{table*}[h]}{%
  \begin{table*}[#4]}
    \centering
    \caption{#2.}
    \label{#3}
    \begin{tabular}{#1}
        \hline\hline
}{%
  \hline\hline
    \end{tabular}
    \end{table*}
}

%
\RequirePackage{import}

%%% Bibliography
\RequirePackage[globalcitecopy,labelstoglobalaux]{bibunits}

\defaultbibliographystyle{pdg}

% Print ``References'' instead of ``Bibliography
% Make review bibliographies start immediately after text, 
% not on a new page
\let\stdthebibliography\thebibliography
\renewcommand{\thebibliography}{%
\renewcommand{\bibname}{References}
\let\chapter\subsection
\stdthebibliography}

\renewcommand{\@bibunitname}{\jobname.\the\@bibunitauxcnt}

%%% Configure line numbers and margin tags for draft mode
\RequirePackage[left]{lineno}
\ifdefined\isdraft
\linenumbers
\RequirePackage[inline]{showlabels}
% The following should cause labels to be rendered in red.
% Unfortunately, when the labels are inline, this causes all 
% text to be red.
%\renewcommand{\showlabelfont}{\tiny\color{red}}
\showlabels{cite}
\showlabels{bibitem}
\fi


% Packages to control style of titles and page headers
\RequirePackage{titling}
\RequirePackage{fancyhdr}

\RequirePackage{titlesec}

\titlespacing*{\chapter}{0pt}{-15pt}{15pt}
\titleformat{\chapter}[block]
{\bfseries\Large}
{\thechapter.}
  {1ex}
%  {\vspace{1ex}\filcenter}
  {\vspace{1ex}}
  [\vspace{1ex}]

\newcommand{\chapterauthor}[1]{%
  {\parindent0pt\vspace*{-25pt}%
  \linespread{1.1}\scshape#1%
  \par\nobreak\vspace*{35pt}}
  \@afterheading%
}

\newcommand\reviewtitle[1]{\renewcommand\@reviewtitle{#1}}
\newcommand\@reviewtitle{}

\newcommand\reviewauthor[1]{\renewcommand\@reviewauthor{#1}}
\newcommand\@reviewauthor{}


\newcommand{\written}[1]{%
  {\parindent0pt%\vspace*{-25pt}%
  \linespread{1.1}{Written #1 by \@reviewauthor.}%
  \par\nobreak\vspace*{20pt}}
  \@afterheading%
}

\newcommand{\revised}[1]{%
  {\parindent0pt%\vspace*{-25pt}%
  \linespread{1.1}{Revised #1 by \@reviewauthor.}%
  \par\nobreak\vspace*{20pt}}
  \@afterheading%
}

\newcommand{\customauthor}[1]{%
  {\parindent0pt%\vspace*{-25pt}%
  \linespread{1.1}#1%
  \par\nobreak\vspace*{20pt}}
  \@afterheading%
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Book specific formatting
\ifrppbook
\RequirePackage[outer=.5in,inner=1in,top=1in,bottom=.5in]{geometry}

\fancyhf{} % clear the fields
\pagestyle{fancy}
% Suppress printing of the word ``Chapter'' in the page headers
\renewcommand{\@chapapp}{}
\fancyhead[LE,RO]{\thepage}
\fancyhead[RE,LO]{\bf\leftmark}
\fancyfoot{}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Web specific formatting
\ifrppweb
\RequirePackage[left=1in,right=1in,top=1in,bottom=1in]{geometry}

\fancyhf{} % clear the fields
\pagestyle{fancy}
% Suppress printing of the word ``Chapter'' in the page headers
\renewcommand{\@chapapp}{}
\setlength{\headheight}{14pt}
\fancyhead[L]{\thepage}
\fancyhead[C]{\bf\leftmark}
\fancyfoot[C]{\scriptsize\today}
\fi

\ifrppbooklet
%\RequirePackage[total={76mm,147mm}]{geometry}
\RequirePackage[paperwidth=76mm,paperheight=147mm,top=5mm,right=5mm,left=5mm,bottom=5mm]{geometry}
\fi

%\RequirePackage[]{thumbs}

%%% Define some useful macros for authors to use

\input{pdgdefs}
\endinput

